const express = require("express");
const path = require("path");
const session = require("express-session");
const SequelizeStore = require("connect-session-sequelize")(session.Store);
const sequelize = require("./sequelize/index");

//Init app
const app = express();

//Load view engine
app.set("views", path.join(__dirname, "views"));
app.set("view engine", "pug");

//Session
const myStore = new SequelizeStore({
    db: sequelize
});
const THIRTY_MINS_IN_MS = 1800000;
app.use(
    session({
        secret: "YSg737mkPuUttBHco1hMaYNb96VKFoMV", //TODO - MOVE TO ENV VARIABLES
        resave: false,
        saveUninitialized: false, //Choosing false is useful for implementing login sessions, reducing server storage usage
        cookie: { secure: false, maxAge: THIRTY_MINS_IN_MS },
        store: myStore
    })
);
myStore.sync(); //Auto-generate session table in database

//Body parser
app.use(express.urlencoded({ extended: true }));

//Check user is authenticated
const { checkUserIsAuthenticated } = require("./middlewares/authentication");
app.use(checkUserIsAuthenticated);

const loginLogoutRoutes = require("./login-logout/login-logout.route");
app.use("/", loginLogoutRoutes);
const dashboardRoutes = require("./dashboard/dashboard.route");
app.use("/", dashboardRoutes);
const spreaderRoutes = require("./spreader/spreader.route");
app.use("/spreader", spreaderRoutes);
const employeeRoutes = require("./employee/employee.route");
app.use("/employee", employeeRoutes);

const port = process.env.PORT || 3000;
app.listen(port, (error) => {
    if (!error)
        console.log(
            "Server is Successfully Running, and App is listening on port " +
                port
        );
    else console.log("Error occurred, server can't start", error);
});
