const sequelize = require("../sequelize/index");
const Employee = sequelize.models.employee;

const employeeClassification = [
    "",
    "Office",
    "Assembly Fitter",
    "Fabricator",
    "Painter",
    "Fab/Fit"
];
const employeeGroup = ["None", "Remote", "Admin", "Superuser"];
const groups = [
    { id: 0, name: "None" },
    { id: 1, name: "Remote" },
    { id: 2, name: "Admin" },
    { id: 3, name: "Superuser" }
];
const classifications = [
    { id: 0, name: "None" },
    { id: 1, name: "Office" },
    { id: 2, name: "Assembly Fitter" },
    { id: 3, name: "Fabricator" },
    { id: 4, name: "Painter" },
    { id: 5, name: "Fab/Fit" }
];

const listEmployees = async (req, res, next) => {
    try {
        const allEmployees = await Employee.findAll({
            order: [["lastName", "ASC"]]
        });
        res.render("employee-list", {
            employees: allEmployees,
            employeeClassification: employeeClassification,
            employeeGroup: employeeGroup
        });
    } catch (err) {
        next(err);
    }
};

const newEmployeeForm = async (req, res, next) => {
    try {
        res.render("employee-new", {
            employeeGroups: groups,
            employeeClassifications: classifications
        });
    } catch (err) {
        next(err);
    }
};

const storeNewEmployee = async (req, res, next) => {
    try {
        const newEmployee = Employee.build({
            firstName: req.body.firstName,
            lastName: req.body.lastName,
            username: req.body.username,
            password: req.body.password,
            groupId: req.body.groupId,
            classificationId: req.body.classificationId,
            isActive: 1
        });
        await newEmployee.save();
        res.redirect("/employee/list");
    } catch (err) {
        next(err);
    }
};

module.exports = {
    listEmployees,
    newEmployeeForm,
    storeNewEmployee
};
